var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/resources/messaging/index.ts
var messaging_exports = {};
__export(messaging_exports, {
  handler: () => handler
});
module.exports = __toCommonJS(messaging_exports);

// src/resources/messaging/appInstance.ts
var import_client_chime_sdk_identity = require("@aws-sdk/client-chime-sdk-identity");
var import_client_ssm = require("@aws-sdk/client-ssm");
var chimeClient = new import_client_chime_sdk_identity.ChimeSDKIdentityClient({
  region: process.env.AWS_REGION
});
var ssmClient = new import_client_ssm.SSMClient({ region: process.env.AWS_REGION });
var createAppInstanceCommandParams;
var createAppInstanceCommandResponse;
var getParameterCommandOutput;
var updatedTags;
var CreateAppInstance = async (uid, props) => {
  updatedTags = [];
  if (props.tags) {
    props.tags.forEach((tag) => {
      updatedTags.push({ Key: tag.key, Value: tag.value });
    });
  }
  createAppInstanceCommandParams = {
    Name: props.name,
    ...props.metadata && { Metadata: props.metadata },
    ...props.clientRequestToken && {
      ClientRequestToken: props.clientRequestToken
    },
    ...updatedTags.length > 0 && { Tags: updatedTags }
  };
  try {
    createAppInstanceCommandResponse = await chimeClient.send(
      new import_client_chime_sdk_identity.CreateAppInstanceCommand(createAppInstanceCommandParams)
    );
  } catch (error) {
    if (error instanceof Error) {
      console.error(error);
      throw error;
    }
  }
  try {
    await ssmClient.send(
      new import_client_ssm.PutParameterCommand({
        Name: `/chime/appInstanceArn/${uid}`,
        Description: "App Instance Arn",
        Value: createAppInstanceCommandResponse.AppInstanceArn,
        Overwrite: true,
        Type: "String"
      })
    );
  } catch (error) {
    if (error instanceof Error) {
      console.error(error);
      throw error;
    }
  }
  return {
    appInstanceArn: createAppInstanceCommandResponse.AppInstanceArn
  };
};
var DeleteAppInstance = async (uid) => {
  try {
    getParameterCommandOutput = await ssmClient.send(
      new import_client_ssm.GetParameterCommand({ Name: `/chime/appInstanceArn/${uid}` })
    );
  } catch (error) {
    if (error instanceof Error) {
      console.error(error);
      throw error;
    }
  }
  try {
    await chimeClient.send(
      new import_client_chime_sdk_identity.DeleteAppInstanceCommand({
        AppInstanceArn: getParameterCommandOutput.Parameter.Value
      })
    );
    await ssmClient.send(
      new import_client_ssm.DeleteParameterCommand({ Name: `/chime/appInstanceArn/${uid}` })
    );
  } catch (error) {
    if (error instanceof Error) {
      console.error(error);
      throw error;
    }
  }
};

// src/resources/messaging/channelFlow.ts
var import_client_chime_sdk_messaging = require("@aws-sdk/client-chime-sdk-messaging");
var import_client_ssm2 = require("@aws-sdk/client-ssm");
var chimeSDKMessagingClient = new import_client_chime_sdk_messaging.ChimeSDKMessagingClient({
  region: process.env.AWS_REGION
});
var ssmClient2 = new import_client_ssm2.SSMClient({ region: process.env.AWS_REGION });
var CreateChannelFlow = async (uid, props) => {
  try {
    const createChannelFlowCommandOutput = await chimeSDKMessagingClient.send(
      new import_client_chime_sdk_messaging.CreateChannelFlowCommand({
        AppInstanceArn: props.appInstanceArn,
        Name: props.name,
        ClientRequestToken: props.clientRequestToken,
        Tags: getUpdatedTags(props.tags),
        Processors: getUpdatedProcessors(props.processors)
      })
    );
    await saveChannelFlowArnToSsm(uid, createChannelFlowCommandOutput.ChannelFlowArn);
    return {
      channelFlowArn: createChannelFlowCommandOutput.ChannelFlowArn
    };
  } catch (error) {
    if (error instanceof Error) {
      console.error(error);
      throw error;
    }
  }
  return {};
};
var UpdateChannelFlow = async (uid, props) => {
  try {
    const channelFlowArn = await getExistingChannelFlowArnFromSsm(uid);
    const updateChannelFlowCommandOutput = await chimeSDKMessagingClient.send(
      new import_client_chime_sdk_messaging.UpdateChannelFlowCommand({
        ChannelFlowArn: channelFlowArn,
        Name: props.name,
        Processors: getUpdatedProcessors(props.processors)
      })
    );
    return {
      channelFlowArn: updateChannelFlowCommandOutput.ChannelFlowArn
    };
  } catch (error) {
    console.error(error);
    throw error;
  }
};
var DeleteChannelFlow = async (uid) => {
  try {
    const channelFlowArn = await getExistingChannelFlowArnFromSsm(uid);
    await chimeSDKMessagingClient.send(
      new import_client_chime_sdk_messaging.DeleteChannelFlowCommand({
        ChannelFlowArn: channelFlowArn
      })
    );
    await deleteChannelFlowArnFromSsm(uid);
  } catch (error) {
    if (error instanceof Error) {
      console.error(error);
      throw error;
    }
  }
};
var saveChannelFlowArnToSsm = async (uid, channelFlowArn) => {
  return ssmClient2.send(
    new import_client_ssm2.PutParameterCommand({
      Name: `/chime/channelFlowArn/${uid}`,
      Description: "channelFlowArn",
      Value: channelFlowArn,
      Overwrite: true,
      Type: "String"
    })
  );
};
var getExistingChannelFlowArnFromSsm = async (uid) => {
  const getParameterCommandOutput2 = await ssmClient2.send(
    new import_client_ssm2.GetParameterCommand({ Name: `/chime/channelFlowArn/${uid}` })
  );
  return getParameterCommandOutput2.Parameter?.Value;
};
var deleteChannelFlowArnFromSsm = async (uid) => {
  return ssmClient2.send(
    new import_client_ssm2.DeleteParameterCommand({ Name: `/chime/channelFlowArn/${uid}` })
  );
};
var getUpdatedProcessors = (processors) => {
  return processors?.map(getUpdatedProcessor) || [];
};
var getUpdatedProcessor = (processor) => {
  return {
    Name: processor.name,
    ExecutionOrder: parseInt(processor.executionOrder),
    FallbackAction: processor.fallbackAction,
    Configuration: {
      Lambda: {
        ResourceArn: processor.configuration.lambda.resourceArn,
        InvocationType: processor.configuration.lambda.invocationType
      }
    }
  };
};
var getUpdatedTags = (tags) => {
  return tags?.map(getUpdatedTag);
};
var getUpdatedTag = (tag) => {
  return { Key: tag.key, Value: tag.value };
};

// src/resources/messaging/dataRetention.ts
var import_client_chime_sdk_identity2 = require("@aws-sdk/client-chime-sdk-identity");
var chimeClient2 = new import_client_chime_sdk_identity2.ChimeSDKIdentityClient({
  region: process.env.AWS_REGION
});
var putDataRetentionOutput;
var putDataRetentionInput;
var PutDataRetention = async (props) => {
  putDataRetentionInput = {
    AppInstanceArn: props.appInstanceArn,
    AppInstanceRetentionSettings: {
      ChannelRetentionSettings: {
        RetentionDays: parseInt(props.dataRetention)
      }
    }
  };
  try {
    putDataRetentionOutput = await chimeClient2.send(
      new import_client_chime_sdk_identity2.PutAppInstanceRetentionSettingsCommand(putDataRetentionInput)
    );
  } catch (error) {
    if (error instanceof Error) {
      console.error(error);
      throw error;
    }
  }
  return {
    appInstanceRetentionSettings: putDataRetentionOutput.AppInstanceRetentionSettings
  };
};

// src/resources/messaging/instanceAdmin.ts
var import_client_chime_sdk_identity3 = require("@aws-sdk/client-chime-sdk-identity");
var import_client_ssm3 = require("@aws-sdk/client-ssm");
var chimeClient3 = new import_client_chime_sdk_identity3.ChimeSDKIdentityClient({
  region: process.env.AWS_REGION
});
var ssmClient3 = new import_client_ssm3.SSMClient({ region: process.env.AWS_REGION });
var createAppInstanceAdminCommandInput;
var createAppInstanceAdminCommandOutput;
var CreateAppInstanceAdmin = async (uid, props) => {
  createAppInstanceAdminCommandInput = {
    AppInstanceArn: props.appInstanceArn,
    AppInstanceAdminArn: props.appInstanceAdminArn
  };
  try {
    createAppInstanceAdminCommandOutput = await chimeClient3.send(
      new import_client_chime_sdk_identity3.CreateAppInstanceAdminCommand(createAppInstanceAdminCommandInput)
    );
  } catch (error) {
    if (error instanceof Error) {
      console.error(error);
      throw error;
    }
  }
  try {
    await ssmClient3.send(
      new import_client_ssm3.PutParameterCommand({
        Name: `/chime/appInstanceAdminArn/${uid}`,
        Description: "appInstanceAdminArn",
        Value: createAppInstanceAdminCommandOutput.AppInstanceAdmin?.Arn,
        Overwrite: true,
        Type: "String"
      })
    );
  } catch (error) {
    if (error instanceof Error) {
      console.error(error);
      throw error;
    }
  }
  return {
    AppInstanceAdminArn: createAppInstanceAdminCommandOutput.AppInstanceAdmin?.Arn,
    AppInstanceAdminName: createAppInstanceAdminCommandOutput.AppInstanceAdmin?.Name
  };
};
var DeleteAppInstanceAdmin = async (uid) => {
  try {
    await ssmClient3.send(
      new import_client_ssm3.DeleteParameterCommand({ Name: `/chime/appInstanceAdminArn/${uid}` })
    );
  } catch (error) {
    if (error instanceof Error) {
      console.error(error);
      throw error;
    }
  }
};

// src/resources/messaging/instanceBot.ts
var import_client_chime_sdk_identity4 = require("@aws-sdk/client-chime-sdk-identity");
var import_client_ssm4 = require("@aws-sdk/client-ssm");
var chimeClient4 = new import_client_chime_sdk_identity4.ChimeSDKIdentityClient({
  region: process.env.AWS_REGION
});
var ssmClient4 = new import_client_ssm4.SSMClient({ region: process.env.AWS_REGION });
var createAppInstanceBotCommandInput;
var createAppInstanceBotCommandOutput;
var updatedTags2;
var CreateAppInstanceBot = async (uid, props) => {
  updatedTags2 = [];
  if (props.tags) {
    props.tags.forEach((tag) => {
      updatedTags2.push({ Key: tag.key, Value: tag.value });
    });
  }
  createAppInstanceBotCommandInput = {
    Configuration: {
      Lex: {
        LexBotAliasArn: props.configuration?.lex?.lexBotAliasArn,
        LocaleId: props.configuration?.lex?.localeId,
        RespondsTo: "STANDARD_MESSAGES",
        // default for now since only option
        ...props.configuration?.lex?.welcomeIntent && {
          WelcomeIntent: props.configuration?.lex?.welcomeIntent
        }
      }
    },
    Name: props.name,
    AppInstanceArn: props.appInstanceArn,
    ...props.metadata && { Metadata: props.metadata },
    ...props.clientRequestToken && {
      ClientRequestToken: props.clientRequestToken
    },
    ...updatedTags2.length > 0 && { Tags: updatedTags2 }
  };
  try {
    createAppInstanceBotCommandOutput = await chimeClient4.send(
      new import_client_chime_sdk_identity4.CreateAppInstanceBotCommand(createAppInstanceBotCommandInput)
    );
  } catch (error) {
    if (error instanceof Error) {
      console.error(error);
      throw error;
    }
  }
  try {
    await ssmClient4.send(
      new import_client_ssm4.PutParameterCommand({
        Name: `/chime/appInstanceBotId/${uid}`,
        Description: "appInstanceBotId",
        Value: createAppInstanceBotCommandOutput.AppInstanceBotArn,
        Overwrite: true,
        Type: "String"
      })
    );
  } catch (error) {
    if (error instanceof Error) {
      console.error(error);
      throw error;
    }
  }
  return {
    appInstanceBot: createAppInstanceBotCommandOutput.AppInstanceBotArn
  };
};
var DeleteAppInstanceBot = async (uid) => {
  try {
    await ssmClient4.send(
      new import_client_ssm4.DeleteParameterCommand({ Name: `/chime/appInstanceBotId/${uid}` })
    );
  } catch (error) {
    if (error instanceof Error) {
      console.error(error);
      throw error;
    }
  }
};

// src/resources/messaging/instanceUser.ts
var import_client_chime_sdk_identity5 = require("@aws-sdk/client-chime-sdk-identity");
var import_client_ssm5 = require("@aws-sdk/client-ssm");
var chimeClient5 = new import_client_chime_sdk_identity5.ChimeSDKIdentityClient({
  region: process.env.AWS_REGION
});
var ssmClient5 = new import_client_ssm5.SSMClient({ region: process.env.AWS_REGION });
var createAppInstanceUserCommandInput;
var createAppInstanceUserCommandOutput;
var updatedTags3;
var CreateAppInstanceUser = async (uid, props) => {
  updatedTags3 = [];
  if (props.tags) {
    props.tags.forEach((tag) => {
      updatedTags3.push({ Key: tag.key, Value: tag.value });
    });
  }
  createAppInstanceUserCommandInput = {
    Name: props.name,
    AppInstanceArn: props.appInstanceArn,
    AppInstanceUserId: props.appInstanceUserId,
    ...props.metadata && { Metadata: props.metadata },
    ...props.clientRequestToken && {
      ClientRequestToken: props.clientRequestToken
    },
    ...updatedTags3.length > 0 && { Tags: updatedTags3 }
  };
  try {
    createAppInstanceUserCommandOutput = await chimeClient5.send(
      new import_client_chime_sdk_identity5.CreateAppInstanceUserCommand(createAppInstanceUserCommandInput)
    );
  } catch (error) {
    if (error instanceof Error) {
      console.error(error);
      throw error;
    }
  }
  try {
    await ssmClient5.send(
      new import_client_ssm5.PutParameterCommand({
        Name: `/chime/appInstanceUserId/${uid}`,
        Description: "appInstanceUserId",
        Value: createAppInstanceUserCommandOutput.AppInstanceUserArn,
        Overwrite: true,
        Type: "String"
      })
    );
  } catch (error) {
    if (error instanceof Error) {
      console.error(error);
      throw error;
    }
  }
  return {
    appInstanceUser: createAppInstanceUserCommandOutput.AppInstanceUserArn
  };
};
var DeleteAppInstanceUser = async (uid) => {
  try {
    await ssmClient5.send(
      new import_client_ssm5.DeleteParameterCommand({ Name: `/chime/appInstanceUserId/${uid}` })
    );
  } catch (error) {
    if (error instanceof Error) {
      console.error(error);
      throw error;
    }
  }
};

// src/resources/messaging/streamingConfig.ts
var import_client_chime_sdk_messaging2 = require("@aws-sdk/client-chime-sdk-messaging");
var chimeClient6 = new import_client_chime_sdk_messaging2.ChimeSDKMessagingClient({
  region: process.env.AWS_REGION
});
var putStreamingConfigurationOutput;
var putStreamingConfigurationInput;
var updatedConfiguration;
var PutStreamingConfiguration = async (props) => {
  updatedConfiguration = [];
  props.streamingConfigs?.forEach((streamingConfig) => {
    updatedConfiguration.push({
      DataType: streamingConfig.dataType,
      ResourceArn: streamingConfig.resourceArn
    });
  });
  putStreamingConfigurationInput = {
    AppInstanceArn: props.appInstanceArn,
    StreamingConfigurations: updatedConfiguration
  };
  console.log("putStreamingConfigurationInput", putStreamingConfigurationInput);
  try {
    putStreamingConfigurationOutput = await chimeClient6.send(
      new import_client_chime_sdk_messaging2.PutMessagingStreamingConfigurationsCommand(
        putStreamingConfigurationInput
      )
    );
  } catch (error) {
    if (error instanceof Error) {
      console.error(error);
      throw error;
    }
  }
  return {
    appInstanceStreamingConfiguration: putStreamingConfigurationOutput.StreamingConfigurations
  };
};

// src/resources/messaging/index.ts
var response = {};
var resourcePropertiesUid;
var requestProperties;
var handler = async (event, context) => {
  console.info("event: ", JSON.stringify(event));
  const resourceType = event.ResourceProperties.resourceType;
  const requestType = event.RequestType;
  resourcePropertiesUid = event.ResourceProperties.uid;
  requestProperties = event.ResourceProperties.properties;
  response.StackId = event.StackId;
  response.RequestId = event.RequestId;
  response.LogicalResourceId = event.LogicalResourceId;
  response.PhysicalResourceId = context.logGroupName;
  switch (resourceType) {
    case "AppInstance":
      switch (requestType) {
        case "Create":
          response.Data = await CreateAppInstance(
            resourcePropertiesUid,
            requestProperties
          );
          response.Status = "SUCCESS";
          response.Reason = "CreateAppInstance successful";
          break;
        case "Update":
          response.Status = "SUCCESS";
          break;
        case "Delete":
          await DeleteAppInstance(resourcePropertiesUid);
          response.Status = "SUCCESS";
          response.Reason = "DeleteAppInstance successful";
          break;
      }
      break;
    case "ChannelFlow":
      switch (requestType) {
        case "Create":
          response.Data = await CreateChannelFlow(
            resourcePropertiesUid,
            requestProperties
          );
          response.Status = "SUCCESS";
          response.Reason = "CreateChannelFlow successful";
          break;
        case "Update":
          response.Data = await UpdateChannelFlow(
            resourcePropertiesUid,
            requestProperties
          );
          response.Status = "SUCCESS";
          response.Reason = "UpdateChannelFlow successful";
          break;
        case "Delete":
          await DeleteChannelFlow(resourcePropertiesUid);
          response.Status = "SUCCESS";
          response.Reason = "DeleteChannelFlow successful";
          break;
      }
      break;
    case "DataRetention":
      switch (requestType) {
        case "Create":
          response.Data = await PutDataRetention(requestProperties);
          response.Status = "SUCCESS";
          response.Reason = "PutDataRetention successful";
          break;
        case "Update":
          response.Data = await PutDataRetention(requestProperties);
          response.Status = "SUCCESS";
          response.Reason = "PutDataRetention successful";
          break;
      }
      break;
    case "AppInstanceAdmin":
      switch (requestType) {
        case "Create":
          response.Data = await CreateAppInstanceAdmin(
            resourcePropertiesUid,
            requestProperties
          );
          response.Status = "SUCCESS";
          response.Reason = "CreateAppInstanceAdmin successful";
          break;
        case "Update":
          response.Status = "SUCCESS";
          break;
        case "Delete":
          await DeleteAppInstanceAdmin(resourcePropertiesUid);
          response.Status = "SUCCESS";
          response.Reason = "DeleteAppInstanceAdmin successful";
          break;
      }
      break;
    case "AppInstanceUser":
      switch (requestType) {
        case "Create":
          response.Data = await CreateAppInstanceUser(
            resourcePropertiesUid,
            requestProperties
          );
          response.Status = "SUCCESS";
          response.Reason = "CreateAppInstanceUser successful";
          break;
        case "Update":
          response.Status = "SUCCESS";
          break;
        case "Delete":
          await DeleteAppInstanceUser(resourcePropertiesUid);
          response.Status = "SUCCESS";
          response.Reason = "DeleteAppInstanceUser successful";
          break;
      }
      break;
    case "AppInstanceBot":
      switch (requestType) {
        case "Create":
          response.Data = await CreateAppInstanceBot(
            resourcePropertiesUid,
            requestProperties
          );
          response.Status = "SUCCESS";
          response.Reason = "CreateAppInstanceBot successful";
          break;
        case "Update":
          response.Status = "SUCCESS";
          break;
        case "Delete":
          await DeleteAppInstanceBot(resourcePropertiesUid);
          response.Status = "SUCCESS";
          response.Reason = "DeleteAppInstanceUser successful";
          break;
      }
      break;
    case "StreamingConfig":
      switch (requestType) {
        case "Create":
          response.Data = await PutStreamingConfiguration(requestProperties);
          response.Status = "SUCCESS";
          response.Reason = "PutStreamingConfiguration successful";
          break;
        case "Update":
          response.Data = await PutStreamingConfiguration(requestProperties);
          response.Status = "SUCCESS";
          response.Reason = "PutStreamingConfiguration successful";
          break;
      }
      break;
  }
  console.log(`Response: ${JSON.stringify(response)}`);
  return response;
};
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  handler
});
