import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { ChimeSDKIdentityClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../ChimeSDKIdentityClient";
import { ListAppInstanceAdminsRequest, ListAppInstanceAdminsResponse } from "../models/models_0";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link ListAppInstanceAdminsCommand}.
 */
export interface ListAppInstanceAdminsCommandInput extends ListAppInstanceAdminsRequest {
}
/**
 * @public
 *
 * The output of {@link ListAppInstanceAdminsCommand}.
 */
export interface ListAppInstanceAdminsCommandOutput extends ListAppInstanceAdminsResponse, __MetadataBearer {
}
declare const ListAppInstanceAdminsCommand_base: {
    new (input: ListAppInstanceAdminsCommandInput): import("@smithy/smithy-client").CommandImpl<ListAppInstanceAdminsCommandInput, ListAppInstanceAdminsCommandOutput, ChimeSDKIdentityClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (__0_0: ListAppInstanceAdminsCommandInput): import("@smithy/smithy-client").CommandImpl<ListAppInstanceAdminsCommandInput, ListAppInstanceAdminsCommandOutput, ChimeSDKIdentityClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Returns a list of the administrators in the <code>AppInstance</code>.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { ChimeSDKIdentityClient, ListAppInstanceAdminsCommand } from "@aws-sdk/client-chime-sdk-identity"; // ES Modules import
 * // const { ChimeSDKIdentityClient, ListAppInstanceAdminsCommand } = require("@aws-sdk/client-chime-sdk-identity"); // CommonJS import
 * const client = new ChimeSDKIdentityClient(config);
 * const input = { // ListAppInstanceAdminsRequest
 *   AppInstanceArn: "STRING_VALUE", // required
 *   MaxResults: Number("int"),
 *   NextToken: "STRING_VALUE",
 * };
 * const command = new ListAppInstanceAdminsCommand(input);
 * const response = await client.send(command);
 * // { // ListAppInstanceAdminsResponse
 * //   AppInstanceArn: "STRING_VALUE",
 * //   AppInstanceAdmins: [ // AppInstanceAdminList
 * //     { // AppInstanceAdminSummary
 * //       Admin: { // Identity
 * //         Arn: "STRING_VALUE",
 * //         Name: "STRING_VALUE",
 * //       },
 * //     },
 * //   ],
 * //   NextToken: "STRING_VALUE",
 * // };
 *
 * ```
 *
 * @param ListAppInstanceAdminsCommandInput - {@link ListAppInstanceAdminsCommandInput}
 * @returns {@link ListAppInstanceAdminsCommandOutput}
 * @see {@link ListAppInstanceAdminsCommandInput} for command's `input` shape.
 * @see {@link ListAppInstanceAdminsCommandOutput} for command's `response` shape.
 * @see {@link ChimeSDKIdentityClientResolvedConfig | config} for ChimeSDKIdentityClient's `config` shape.
 *
 * @throws {@link BadRequestException} (client fault)
 *  <p>The input parameters don't match the service's restrictions.</p>
 *
 * @throws {@link ForbiddenException} (client fault)
 *  <p>The client is permanently forbidden from making the request.</p>
 *
 * @throws {@link ResourceLimitExceededException} (client fault)
 *  <p>The request exceeds the resource limit.</p>
 *
 * @throws {@link ServiceFailureException} (server fault)
 *  <p>The service encountered an unexpected error.</p>
 *
 * @throws {@link ServiceUnavailableException} (server fault)
 *  <p>The service is currently unavailable.</p>
 *
 * @throws {@link ThrottledClientException} (client fault)
 *  <p>The client exceeded its request rate limit.</p>
 *
 * @throws {@link UnauthorizedClientException} (client fault)
 *  <p>The client is not currently authorized to make the request.</p>
 *
 * @throws {@link ChimeSDKIdentityServiceException}
 * <p>Base exception class for all service exceptions from ChimeSDKIdentity service.</p>
 *
 * @public
 */
export declare class ListAppInstanceAdminsCommand extends ListAppInstanceAdminsCommand_base {
}
